@@ -40,6 +40,13 @@
 
 #define PI 3.14159265358979323846
 
+static int64_t get_dynamical_matrix_at_q(
+    double (*dynamical_matrix)[2], const int64_t num_patom,
+    const int64_t num_satom, const double *fc, const double q[3],
+    const double (*svecs)[3], const int64_t (*multi)[2], const double *mass,
+    const int64_t *s2p_map, const int64_t *p2s_map,
+    const double (*charge_sum)[3][3], const int64_t hermitianize,
+    const int64_t use_openmp);
 static void add_dynmat_dd_at_q(
     double (*dynamical_matrices)[2], const double q[3], const double *fc,
     const double (*positions)[3], const int64_t num_patom, const double *masses,
@@ -92,14 +99,15 @@ static void transform_dynmat_to_fc_ij(
     const int64_t num_satom);
 static void get_q_cart(double q_cart[3], const double q[3],
                        const double reciprocal_lattice[3][3]);
-static void get_dynmat_want(
+static void get_dynmat_wang(
     double (*dynamical_matrices)[2], const double qpoint[3], const double *fc,
     const double (*svecs)[3], const int64_t (*multi)[2],
     const int64_t num_patom, const int64_t num_satom, const double *masses,
     const int64_t *p2s_map, const int64_t *s2p_map, const double (*born)[3][3],
     const double dielectric[3][3], const double (*reciprocal_lattice)[3],
     const double *q_direction, const double *q_dir_cart,
-    const double nac_factor, const double q_zero_tolerance);
+    const double nac_factor, const double q_zero_tolerance,
+    const int64_t hermitianize);
 
 /// @brief Calculate dynamical matrices with openmp over q-points
 /// use_Wang_NAC: Wang et al.
@@ -116,8 +124,8 @@ int64_t dym_dynamical_matrices_with_dd_openmp_over_qpoints(
     const double dielectric[3][3], const double (*reciprocal_lattice)[3],
     const double *q_direction, const double nac_factor,
     const double (*dd_q0)[2], const double (*G_list)[3],
-    const int64_t num_G_points, const double lambda,
-    const int64_t use_Wang_NAC) {
+    const int64_t num_G_points, const double lambda, const int64_t use_Wang_NAC,
+    const int64_t hermitianize) {
     int64_t i, n, adrs_shift;
     double *q_dir_cart;
     double q_zero_tolerance;
@@ -136,20 +144,21 @@ int64_t dym_dynamical_matrices_with_dd_openmp_over_qpoints(
 #pragma omp parallel for
 #endif
         for (i = 0; i < n_qpoints; i++) {
-            get_dynmat_want(dynamical_matrices + adrs_shift * i, qpoints[i], fc,
+            get_dynmat_wang(dynamical_matrices + adrs_shift * i, qpoints[i], fc,
                             svecs, multi, num_patom, num_satom, masses, p2s_map,
                             s2p_map, born, dielectric, reciprocal_lattice,
                             q_direction, q_dir_cart, nac_factor,
-                            q_zero_tolerance);
+                            q_zero_tolerance, hermitianize);
         }
     } else {
 #ifdef _OPENMP
 #pragma omp parallel for
 #endif
         for (i = 0; i < n_qpoints; i++) {
-            dym_get_dynamical_matrix_at_q(
-                dynamical_matrices + adrs_shift * i, num_patom, num_satom, fc,
-                qpoints[i], svecs, multi, masses, s2p_map, p2s_map, NULL, 0);
+            get_dynamical_matrix_at_q(dynamical_matrices + adrs_shift * i,
+                                      num_patom, num_satom, fc, qpoints[i],
+                                      svecs, multi, masses, s2p_map, p2s_map,
+                                      NULL, hermitianize, 0);
             if (dd_q0) {  // NAC by Gonze and Lee if dd_in is not NULL
                 add_dynmat_dd_at_q(dynamical_matrices + adrs_shift * i,
                                    qpoints[i], fc, positions, num_patom, masses,
@@ -167,15 +176,16 @@ int64_t dym_dynamical_matrices_with_dd_openmp_over_qpoints(
     return 0;
 }
 
-static void get_dynmat_want(
+static void get_dynmat_wang(
     double (*dynamical_matrices)[2], const double qpoint[3], const double *fc,
     const double (*svecs)[3], const int64_t (*multi)[2],
     const int64_t num_patom, const int64_t num_satom, const double *masses,
     const int64_t *p2s_map, const int64_t *s2p_map, const double (*born)[3][3],
     const double dielectric[3][3], const double (*reciprocal_lattice)[3],
     const double *q_direction, const double *q_dir_cart,
-    const double nac_factor, const double q_zero_tolerance) {
-    double(*charge_sum)[3][3];
+    const double nac_factor, const double q_zero_tolerance,
+    const int64_t hermitianize) {
+    double (*charge_sum)[3][3];
     double q_cart[3];
     double q_norm;
     int64_t n;
@@ -187,7 +197,7 @@ static void get_dynmat_want(
     q_norm = sqrt(q_cart[0] * q_cart[0] + q_cart[1] * q_cart[1] +
                   q_cart[2] * q_cart[2]);
     charge_sum =
-        (double(*)[3][3])malloc(sizeof(double[3][3]) * num_patom * num_patom);
+        (double (*)[3][3])malloc(sizeof(double[3][3]) * num_patom * num_patom);
 
     if (q_norm < q_zero_tolerance) {
         if (q_direction) {
@@ -195,23 +205,23 @@ static void get_dynmat_want(
                 charge_sum, num_patom,
                 nac_factor / n / get_dielectric_part(q_dir_cart, dielectric),
                 q_dir_cart, born);
-            dym_get_dynamical_matrix_at_q(
-                dynamical_matrices, num_patom, num_satom, fc, qpoint, svecs,
-                multi, masses, s2p_map, p2s_map, charge_sum, 0);
+            get_dynamical_matrix_at_q(dynamical_matrices, num_patom, num_satom,
+                                      fc, qpoint, svecs, multi, masses, s2p_map,
+                                      p2s_map, charge_sum, hermitianize, 0);
 
         } else {
-            dym_get_dynamical_matrix_at_q(dynamical_matrices, num_patom,
-                                          num_satom, fc, qpoint, svecs, multi,
-                                          masses, s2p_map, p2s_map, NULL, 0);
+            get_dynamical_matrix_at_q(dynamical_matrices, num_patom, num_satom,
+                                      fc, qpoint, svecs, multi, masses, s2p_map,
+                                      p2s_map, NULL, hermitianize, 0);
         }
     } else {
         dym_get_charge_sum(
             charge_sum, num_patom,
             nac_factor / n / get_dielectric_part(q_cart, dielectric), q_cart,
             born);
-        dym_get_dynamical_matrix_at_q(dynamical_matrices, num_patom, num_satom,
-                                      fc, qpoint, svecs, multi, masses, s2p_map,
-                                      p2s_map, charge_sum, 0);
+        get_dynamical_matrix_at_q(dynamical_matrices, num_patom, num_satom, fc,
+                                  qpoint, svecs, multi, masses, s2p_map,
+                                  p2s_map, charge_sum, hermitianize, 0);
     }
 
     free(charge_sum);
@@ -227,11 +237,11 @@ static void add_dynmat_dd_at_q(
     const double (*G_list)[3], const int64_t num_G_points, const double lambda,
     const double tolerance) {
     int64_t i, j, k, l, adrs;
-    double(*dd)[2];
+    double (*dd)[2];
     double q_cart[3];
     double mm;
 
-    dd = (double(*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
+    dd = (double (*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
     get_q_cart(q_cart, q, reciprocal_lattice);
     dym_get_recip_dipole_dipole(dd, dd_q0, G_list, num_G_points, num_patom,
                                 q_cart, q_dir_cart, born, dielectric, positions,
@@ -254,40 +264,6 @@ static void add_dynmat_dd_at_q(
     dd = NULL;
 }
 
-/// @brief charge_sum is NULL if G-L NAC or no-NAC.
-int64_t dym_get_dynamical_matrix_at_q(
-    double (*dynamical_matrix)[2], const int64_t num_patom,
-    const int64_t num_satom, const double *fc, const double q[3],
-    const double (*svecs)[3], const int64_t (*multi)[2], const double *mass,
-    const int64_t *s2p_map, const int64_t *p2s_map,
-    const double (*charge_sum)[3][3], const int64_t use_openmp) {
-    int64_t i, j, ij;
-
-    if (use_openmp) {
-#ifdef _OPENMP
-#pragma omp parallel for
-#endif
-        for (ij = 0; ij < num_patom * num_patom; ij++) {
-            get_dynmat_ij(dynamical_matrix, num_patom, num_satom, fc, q, svecs,
-                          multi, mass, s2p_map, p2s_map, charge_sum,
-                          ij / num_patom,  /* i */
-                          ij % num_patom); /* j */
-        }
-    } else {
-        for (i = 0; i < num_patom; i++) {
-            for (j = 0; j < num_patom; j++) {
-                get_dynmat_ij(dynamical_matrix, num_patom, num_satom, fc, q,
-                              svecs, multi, mass, s2p_map, p2s_map, charge_sum,
-                              i, j);
-            }
-        }
-    }
-
-    make_Hermitian(dynamical_matrix, num_patom * 3);
-
-    return 0;
-}
-
 void dym_get_recip_dipole_dipole(
     double (*dd)[2],           /* [natom, 3, natom, 3, (real,imag)] */
     const double (*dd_q0)[2],  /* [natom, 3, 3, (real,imag)] */
@@ -299,10 +275,10 @@ void dym_get_recip_dipole_dipole(
     const double factor,    /* 4pi/V*unit-conv */
     const double lambda, const double tolerance, const int64_t use_openmp) {
     int64_t i, k, l, adrs, adrs_sum;
-    double(*dd_tmp)[2];
+    double (*dd_tmp)[2];
 
     dd_tmp =
-        (double(*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
+        (double (*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
 
     for (i = 0; i < num_patom * num_patom * 9; i++) {
         dd[i][0] = 0;
@@ -347,12 +323,12 @@ void dym_get_recip_dipole_dipole_q0(
     const double lambda, const double tolerance, const int64_t use_openmp) {
     int64_t i, j, k, l, adrs_tmp, adrs, adrsT;
     double zero_vec[3];
-    double(*dd_tmp1)[2], (*dd_tmp2)[2];
+    double (*dd_tmp1)[2], (*dd_tmp2)[2];
 
     dd_tmp1 =
-        (double(*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
+        (double (*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
     dd_tmp2 =
-        (double(*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
+        (double (*)[2])malloc(sizeof(double[2]) * num_patom * num_patom * 9);
 
     for (i = 0; i < num_patom * num_patom * 9; i++) {
         dd_tmp1[i][0] = 0;
@@ -430,9 +406,9 @@ void dym_get_charge_sum(
     const double factor, /* 4pi/V*unit-conv and denominator */
     const double q_cart[3], const double (*born)[3][3]) {
     int64_t i, j, k, a, b;
-    double(*q_born)[3];
+    double (*q_born)[3];
 
-    q_born = (double(*)[3])malloc(sizeof(double[3]) * num_patom);
+    q_born = (double (*)[3])malloc(sizeof(double[3]) * num_patom);
     for (i = 0; i < num_patom; i++) {
         for (j = 0; j < 3; j++) {
             q_born[i][j] = 0;
@@ -499,6 +475,43 @@ void dym_transform_dynmat_to_fc(
     }
 }
 
+/// @brief charge_sum is NULL if G-L NAC or no-NAC.
+static int64_t get_dynamical_matrix_at_q(
+    double (*dynamical_matrix)[2], const int64_t num_patom,
+    const int64_t num_satom, const double *fc, const double q[3],
+    const double (*svecs)[3], const int64_t (*multi)[2], const double *mass,
+    const int64_t *s2p_map, const int64_t *p2s_map,
+    const double (*charge_sum)[3][3], const int64_t hermitianize,
+    const int64_t use_openmp) {
+    int64_t i, j, ij;
+
+    if (use_openmp) {
+#ifdef _OPENMP
+#pragma omp parallel for
+#endif
+        for (ij = 0; ij < num_patom * num_patom; ij++) {
+            get_dynmat_ij(dynamical_matrix, num_patom, num_satom, fc, q, svecs,
+                          multi, mass, s2p_map, p2s_map, charge_sum,
+                          ij / num_patom,  /* i */
+                          ij % num_patom); /* j */
+        }
+    } else {
+        for (i = 0; i < num_patom; i++) {
+            for (j = 0; j < num_patom; j++) {
+                get_dynmat_ij(dynamical_matrix, num_patom, num_satom, fc, q,
+                              svecs, multi, mass, s2p_map, p2s_map, charge_sum,
+                              i, j);
+            }
+        }
+    }
+
+    if (hermitianize) {
+        make_Hermitian(dynamical_matrix, num_patom * 3);
+    }
+
+    return 0;
+}
+
 /// @brief charge_sum is NULL if G-L NAC or no-NAC.
 static void get_dynmat_ij(double (*dynamical_matrix)[2],
                           const int64_t num_patom, const int64_t num_satom,
@@ -601,9 +614,9 @@ static void get_dd(double (*dd_part)[2], /* [natom, 3, natom, 3, (real,imag)] */
     int64_t i, j, g;
     double q_K[3];
     double norm, dielectric_part, L2;
-    double(*KK)[3][3];
+    double (*KK)[3][3];
 
-    KK = (double(*)[3][3])malloc(sizeof(double[3][3]) * num_G);
+    KK = (double (*)[3][3])malloc(sizeof(double[3][3]) * num_G);
     L2 = 4 * lambda * lambda;
 
     /* sum over K = G + q and over G (i.e. q=0) */
