@@ -45,7 +45,7 @@ import sys
 import numpy as np
 
 from phonopy.interface.vasp import check_forces, get_drift_forces
-from phonopy.structure.atoms import PhonopyAtoms as Atoms
+from phonopy.structure.atoms import PhonopyAtoms
 
 
 # FK 2018/07/19
@@ -101,9 +101,11 @@ def read_aims(filename):
             ]
             positions[n] = pos
     if None in magmoms:
-        atoms = Atoms(cell=cell, symbols=symbols, positions=positions)
+        atoms = PhonopyAtoms(cell=cell, symbols=symbols, positions=positions)
     else:
-        atoms = Atoms(cell=cell, symbols=symbols, positions=positions, magmoms=magmoms)
+        atoms = PhonopyAtoms(
+            cell=cell, symbols=symbols, positions=positions, magmoms=magmoms
+        )
 
     return atoms
 
@@ -115,17 +117,17 @@ def write_aims(filename, atoms):
     lines += "# | generated by phonopy.FHIaims.write_aims() \n"
 
     lattice_vector_line = "lattice_vector " + "%16.16f " * 3 + "\n"
-    for vec in atoms.get_cell():
+    for vec in atoms.cell:
         lines += lattice_vector_line % tuple(vec)
 
-    N = atoms.get_number_of_atoms()
+    N = len(atoms)
 
     atom_line = "atom " + "%16.16f " * 3 + "%s \n"
-    positions = atoms.get_positions()
-    symbols = atoms.get_chemical_symbols()
+    positions = atoms.positions
+    symbols = atoms.symbols
 
     initial_moment_line = "initial_moment %16.6f\n"
-    magmoms = atoms.get_magnetic_moments()
+    magmoms = atoms.magnetic_moments
 
     for n in range(N):
         lines += atom_line % (tuple(positions[n]) + (symbols[n],))
@@ -136,7 +138,7 @@ def write_aims(filename, atoms):
         f.write(lines)
 
 
-class Atoms_with_forces(Atoms):
+class Atoms_with_forces(PhonopyAtoms):
     """Hack to phonopy.atoms to maintain ASE compatibility also for forces."""
 
     def get_forces(self):
@@ -161,7 +163,7 @@ def read_aims_output(filename):
             N = int(line.split()[5])
         elif "| Unit cell:" in line:
             cell = []
-            for i in range(3):
+            for _ in range(3):
                 ll += 1
                 vec = lmap(float, lines[ll].split()[1:4])
                 cell.append(vec)
@@ -177,7 +179,7 @@ def read_aims_output(filename):
             ll += 1
             symbols = []
             positions = []
-            for n in range(N):
+            for _ in range(N):
                 ll += 1
                 fields = lines[ll].split()
                 sym = fields[i_sym]
@@ -186,7 +188,7 @@ def read_aims_output(filename):
                 positions.append(pos)
         elif "Total atomic forces" in line:
             forces = []
-            for i in range(N):
+            for _ in range(N):
                 ll += 1
                 force = lmap(float, lines[ll].split()[-3:])
                 forces.append(force)
