@@ -37,6 +37,7 @@
 import itertools
 import math
 import sys
+import warnings
 
 import numpy as np
 
@@ -44,7 +45,7 @@ from phonopy.interface.vasp import (
     get_drift_forces,
     sort_positions_by_symbols,
 )
-from phonopy.structure.atoms import PhonopyAtoms, symbol_map
+from phonopy.structure.atoms import PhonopyAtoms
 
 
 def parse_set_of_forces(num_atoms, forces_filenames, verbose=True):
@@ -102,10 +103,6 @@ def read_fleur(filename):
     tags = fleur_in.get_variables()
     avec = [tags["avec"][i] for i in range(3)]
     speci = tags["atoms"]["speci"]
-    symbols = [
-        list(symbol_map.keys())[list(symbol_map.values()).index(math.floor(float(x)))]
-        for x in speci
-    ]
     numbers = [math.floor(float(x)) for x in speci]
 
     for i, n in enumerate(numbers):
@@ -115,13 +112,10 @@ def read_fleur(filename):
                     numbers[i] = j
                     break
     pos_all = []
-    num_all = []
     for _, pos in zip(numbers, tags["atoms"]["positions"]):
         pos_all += pos
-    num_all = [symbol_map[s] for s in symbols]
-
     return (
-        PhonopyAtoms(numbers=num_all, cell=avec, scaled_positions=pos_all),
+        PhonopyAtoms(numbers=numbers, cell=avec, scaled_positions=pos_all),
         speci,
         fleur_in._restlines,
     )
@@ -158,6 +152,24 @@ def get_fleur_structure(cell, speci, N, restlines):
     (num_atoms, symbols, scaled_positions, sort_list) = sort_positions_by_symbols(
         cell.symbols, cell.scaled_positions
     )
+    if restlines is None:
+        restlines = [
+            "Title line (Generated by phonopy)",
+            "\nAdditional job info here\n",
+        ]
+        warnings.warn(
+            "No additional job info given. Writing minimal file.",
+            UserWarning,
+            stacklevel=2,
+        )
+    if speci is None:
+        speci = cell.numbers
+        warnings.warn(
+            "Atomic symbols not given. Using atomic numbers instead."
+            " If you would like to uniquely identify atoms, please populate `speci`.",
+            UserWarning,
+            stacklevel=2,
+        )
     specilong = list(
         itertools.chain.from_iterable(itertools.repeat(x, N) for x in speci)
     )
@@ -167,7 +179,7 @@ def get_fleur_structure(cell, speci, N, restlines):
     lines += "1.0 1.0 1.0 \n \n"
     lines += str(sum(num_atoms)) + "\n"
     for i in range(sum(num_atoms)):
-        lines += specilong[i].ljust(6)
+        lines += str(specilong[i]).ljust(6)
         currentpos = str(scaled_positions[i]).replace("[", "")
         currentpos = currentpos.replace("]", "").split()
 
