@@ -34,11 +34,19 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
+
+import io
+import os
 import sys
+import typing
+import warnings
 from collections import OrderedDict
 
 import numpy as np
+from numpy.typing import NDArray
 
+from phonopy import Phonopy
 from phonopy.file_IO import (
     iter_collect_forces,
     write_FORCE_CONSTANTS,
@@ -52,7 +60,7 @@ from phonopy.interface.vasp import (
 )
 from phonopy.physical_units import get_physical_units
 from phonopy.structure.atoms import PhonopyAtoms, split_symbol_and_index, symbol_map
-from phonopy.structure.cells import get_primitive, get_supercell
+from phonopy.structure.cells import Primitive, get_primitive, get_supercell
 
 
 def parse_set_of_forces(num_atoms, forces_filenames, verbose=True):
@@ -107,7 +115,7 @@ def read_pwscf(filename):
     for symnum in species:  # symnum is like 'H', 'H1', 'H2', ...
         symbol, num = split_symbol_and_index(symnum)
         if symbol not in symbol_map:
-            RuntimeError(f"Element {symbol} is not supported.")
+            raise RuntimeError(f"Element {symbol} is not supported.")
         if num > 0:
             use_given_masses = True
 
@@ -162,6 +170,12 @@ def write_supercells_with_displacements(
 
 def get_pwscf_structure(cell, pp_filenames=None):
     """Return QE structure in text."""
+    if pp_filenames is None:
+        warnings.warn(
+            "Optional structure information (pp_filenames) is missing.\n"
+            "You will need to manually add pp filenames to the qe input file.",
+            stacklevel=2,
+        )
     lattice = cell.cell
     positions = cell.scaled_positions
     masses = cell.masses
@@ -318,7 +332,7 @@ class PwscfIn:
             raise RuntimeError("As a unit, alat, angstrom, and bohr can be only used.")
 
         if len(self._values[1:]) < 9:
-            raise RuntimeError("%s is wrongly set." % self._current_tag_name)
+            raise RuntimeError("%s is malformed." % self._current_tag_name)
 
         lattice = np.reshape([float(x) for x in self._values[1:10]], (3, 3))
         self._tags["cell_parameters"] = lattice * factor
@@ -417,7 +431,7 @@ class PH_Q2R:
     the number of atoms in unit cell and n_satom is the number of
     atoms in super cell, i.e., u_atom * prod(dim). When using this
     force constants data from phonopy with primitive cell that is
-    differnt from unit cell, force constants have to be regenerated
+    different from unit cell, force constants have to be regenerated
     for the primitive cell, which is not done in this class.
 
     Treatment of non-analytical term correction (NAC) is different
@@ -444,7 +458,7 @@ class PH_Q2R:
         dtype='double'
         shape=(natom_prim, natom_super, 3, 3) for compact fc or
               (natom_super, natom_super, 3, 3) for full fc
-    dimenstion : ndarray
+    dimension : ndarray
         Supercell dimensions (not matrix)
         dtype='intc'
         shape=(3,)
@@ -463,18 +477,18 @@ class PH_Q2R:
 
     """
 
-    def __init__(self, filename, symprec=1e-5):
+    def __init__(self, filename: str | os.PathLike | typing.IO, symprec: float = 1e-5):
         """Init method."""
-        self.fc = None
-        self.dimension = None
-        self.epsilon = None
-        self.borns = None
-        self.primitive = None
-        self.supercell = None
+        self.fc: NDArray | None = None
+        self.dimension: NDArray | None = None
+        self.epsilon: NDArray | None = None
+        self.borns: NDArray | None = None
+        self.primitive: Primitive | None = None
+        self.supercell: PhonopyAtoms | None = None
         self._symprec = symprec
         self._filename = filename
 
-    def run(self, cell, is_full_fc=False, parse_fc=True):
+    def run(self, cell: PhonopyAtoms, is_full_fc: bool = False, parse_fc: bool = True):
         """Make supercell force constants readable for phonopy.
 
         Note
@@ -495,23 +509,44 @@ class PH_Q2R:
             False may be used when expected to parse only epsilon and born.
 
         """
-        with open(self._filename) as f:
-            fc_dct = self._parse_q2r(f)
-            self.dimension = fc_dct["dimension"]
-            self.epsilon = fc_dct["dielectric"]
-            self.borns = fc_dct["born"]
-            if parse_fc:
-                (self.fc, self.primitive, self.supercell) = self._arrange_supercell_fc(
-                    cell, fc_dct["fc"], is_full_fc=is_full_fc
-                )
+        if isinstance(self._filename, io.IOBase):
+            fc_dct = self._parse_q2r(self._filename)
+        else:
+            assert isinstance(self._filename, (str, os.PathLike))
+            with open(self._filename) as f:
+                fc_dct = self._parse_q2r(f)
+
+        self.dimension = fc_dct["dimension"]
+        self.epsilon = fc_dct["dielectric"]
+        self.borns = fc_dct["born"]
+        if parse_fc:
+            (self.fc, self.primitive, self.supercell) = self._get_phonopy_supercell_fc(
+                cell, fc_dct["fc"], is_full_fc=is_full_fc
+            )
+
+    def save(self, filename="phonopy_params_q2r.yaml"):
+        """Save the q2r output to a file."""
+        if self.primitive is None:
+            raise RuntimeError("Run PH_Q2R.run() before saving.")
+
+        ph = Phonopy(
+            self.primitive,
+            supercell_matrix=self.dimension,
+            calculator="qe",
+        )
+        ph.force_constants = self.fc
+        ph.save(filename)
+
+    def write_force_constants(self, fc_format: str = "hdf5"):
+        """Write force constants to file in hdf5."""
+        if self.primitive is None:
+            raise RuntimeError("Run PH_Q2R.run() before writing force constants.")
 
-    def write_force_constants(self, fc_format="hdf5"):
-        """Write force constatns to file in hdf5."""
         if self.fc is not None:
             if fc_format == "hdf5":
                 write_force_constants_to_hdf5(self.fc, p2s_map=self.primitive.p2s_map)
             else:
-                write_FORCE_CONSTANTS(self.fc)
+                write_FORCE_CONSTANTS(self.fc, p2s_map=self.primitive.p2s_map)
 
     def _parse_q2r(self, f):
         """Parse q2r output file.
@@ -567,41 +602,41 @@ class PH_Q2R:
     def _parse_fc(self, f, natom, dim):
         """Parse force constants part.
 
-        Physical unit of force cosntants in the file is Ry/au^2.
+        Physical unit of force constants in the file is Ry/au^2.
 
         """
         ndim = np.prod(dim)
         fc = np.zeros((natom, natom * ndim, 3, 3), dtype="double", order="C")
-        for k, ll, i, j in np.ndindex((3, 3, natom, natom)):
-            line = f.readline()
-            for i_dim in range(ndim):
+        for k, ll, i, j in np.ndindex((3, 3, natom, natom)):  # xyz2 xzy1 p2 p1
+            line = f.readline()  # xyz2 xzy1 p2 p1
+            for i_dim in range(ndim):  # lattice translation, see _get_q2r_positions
                 line = f.readline()
-                # fc[i, j * ndim + i_dim, k, l] = float(line.split()[3])
                 fc[j, i * ndim + i_dim, ll, k] = float(line.split()[3])
         return fc
 
-    def _arrange_supercell_fc(self, cell, q2r_fc, is_full_fc=False):
+    def _get_phonopy_supercell_fc(
+        self, cell: PhonopyAtoms, q2r_fc: NDArray, is_full_fc: bool = False
+    ):
         dim = self.dimension
         q2r_spos = self._get_q2r_positions(cell)
+        assert dim is not None
         scell = get_supercell(cell, np.diag(dim))
         pcell = get_primitive(scell, np.diag(1.0 / dim))
 
-        diff = cell.get_scaled_positions() - pcell.get_scaled_positions()
+        diff = cell.scaled_positions - pcell.scaled_positions
         diff -= np.rint(diff)
         assert (np.abs(diff) < 1e-8).all()
-        assert scell.get_number_of_atoms() == len(q2r_spos)
+        assert len(scell) == len(q2r_spos)
 
-        site_map = self._get_site_mapping(
-            scell.get_scaled_positions(), q2r_spos, scell.get_cell()
-        )
-        natom = pcell.get_number_of_atoms()
+        site_map = self._get_site_mapping(scell.scaled_positions, q2r_spos, scell.cell)
+        natom = len(pcell)
+        assert dim is not None
         ndim = np.prod(dim)
         natom_s = natom * ndim
 
         if is_full_fc:
             fc = np.zeros((natom_s, natom_s, 3, 3), dtype="double", order="C")
-            p2s = pcell.get_primitive_to_supercell_map()
-            fc[p2s, :] = q2r_fc[:, site_map]
+            fc[pcell.p2s_map, :] = q2r_fc[:, site_map]
             distribute_force_constants_by_translations(fc, pcell)
         else:
             fc = np.zeros((natom, natom_s, 3, 3), dtype="double", order="C")
@@ -609,17 +644,40 @@ class PH_Q2R:
 
         return fc, pcell, scell
 
-    def _get_q2r_positions(self, cell):
+    def _get_q2r_positions(self, cell: PhonopyAtoms) -> NDArray:
+        """Define order of atomic positions in q2r.
+
+        In [1]: dim = np.array([2, 2, 2])
+        In [2]: trans = [x[::-1] for x in np.ndindex(tuple(dim[::-1]))]
+        In [3]: trans
+        Out[3]:
+        [(0, 0, 0),
+        (1, 0, 0),
+        (0, 1, 0),
+        (1, 1, 0),
+        (0, 0, 1),
+        (1, 0, 1),
+        (0, 1, 1),
+        (1, 1, 1)]
+
+        """
         dim = self.dimension
-        natom = cell.get_number_of_atoms()
+        natom = len(cell)
+        assert dim is not None
         ndim = np.prod(dim)
         spos = np.zeros((natom * np.prod(dim), 3), dtype="double", order="C")
+        # See the docstring for the order of lattice translation in QE.
         trans = [x[::-1] for x in np.ndindex(tuple(dim[::-1]))]
-        for i, p in enumerate(cell.get_scaled_positions()):
+        for i, p in enumerate(cell.scaled_positions):
             spos[i * ndim : (i + 1) * ndim] = (trans + p) / dim
         return spos
 
-    def _get_site_mapping(self, spos, q2r_spos, lattice):
+    def _get_site_mapping(self, spos: NDArray, q2r_spos: NDArray, lattice: NDArray):
+        """Get mapping from supercell to q2r positions.
+
+        site_map[i] gives the index of q2r_spos corresponding to spos[i].
+
+        """
         site_map = []
         for _, p in enumerate(spos):
             diff = q2r_spos - p
