@@ -39,14 +39,16 @@ from __future__ import annotations
 import io
 import os
 import sys
+import typing
 import warnings
 import xml.etree.cElementTree as etree
 import xml.parsers.expat
 from collections import Counter
 from collections.abc import Sequence
-from typing import Literal, Optional, Union
+from typing import Literal
 
 import numpy as np
+from numpy.typing import ArrayLike, NDArray
 
 from phonopy.file_IO import (
     get_io_module_to_decompress,
@@ -100,7 +102,7 @@ def get_scaled_positions_lines(scaled_positions):
 
 
 def sort_positions_by_symbols(
-    symbols: Sequence, positions: Optional[np.ndarray] = None
+    symbols: Sequence[str | int] | ArrayLike, positions: NDArray | None = None
 ):
     """Sort atomic positions by symbols.
 
@@ -158,8 +160,8 @@ def sort_positions_by_symbols(
 def _get_forces_points_and_energy(
     fp: io.IOBase,
     use_expat: bool = True,
-    filename: Optional[Union[str, os.PathLike]] = None,
-) -> tuple[np.ndarray, Optional[np.ndarray], Optional[float]]:
+    filename: str | os.PathLike | None = None,
+) -> tuple[np.ndarray, np.ndarray | None, float | None]:
     vasprun = Vasprun(fp, use_expat=use_expat)
     try:
         forces = vasprun.read_forces()
@@ -180,7 +182,7 @@ def _get_forces_points_and_energy(
 
 def parse_set_of_forces(
     num_atoms: int,
-    forces_filenames: Sequence[Union[str, bytes, os.PathLike, io.IOBase]],
+    forces_filenames: Sequence[str | os.PathLike | typing.IO],
     use_expat: bool = True,
     verbose: bool = True,
 ) -> dict:
@@ -392,12 +394,12 @@ def get_vasp_structure_lines(
     direct: bool = True,
     is_vasp5: bool = True,
     is_vasp4: bool = False,
-    first_line_str: Optional[str] = None,
+    first_line_str: str | None = None,
 ):
     """Generate POSCAR text lines as a list from PhonopyAtoms instance.
 
     direct : bool
-        Dummy argument. This doesn nothing.
+        Dummy argument. This does nothing.
     is_vasp5 : bool
         Deprecated. This is replaced by ``is_vasp4 = not is_vasp5``.
 
@@ -441,7 +443,7 @@ def write_supercells_with_displacements(
 
 
 def _get_vasp_structure_header_lines(
-    cell: PhonopyAtoms, is_vasp4: bool = False, first_line_str: Optional[str] = None
+    cell: PhonopyAtoms, is_vasp4: bool = False, first_line_str: str | None = None
 ):
     (num_atoms, symbols, scaled_positions, _) = sort_positions_by_symbols(
         cell.symbols, cell.scaled_positions
@@ -640,14 +642,14 @@ class Vasprun:
             vasprun_etree = self._parse_etree_vasprun_xml(tag="varray")
             return self._get_forces(vasprun_etree)
 
-    def read_points(self) -> Optional[np.ndarray]:
+    def read_points(self) -> np.ndarray | None:
         """Read forces either using expat or etree."""
         if self._use_expat:
             return self._parse_expat_vasprun_xml(target="points")
         else:
             return None
 
-    def read_energy(self) -> Optional[float]:
+    def read_energy(self) -> float | None:
         """Read energy using expat and etree is not supported."""
         if self._use_expat:
             return self._parse_expat_vasprun_xml(target="energy")
@@ -674,7 +676,7 @@ class Vasprun:
 
     def _get_force_constants(
         self, vasprun_etree
-    ) -> tuple[Optional[np.ndarray], Optional[list[str]]]:
+    ) -> tuple[np.ndarray | None, list[str] | None]:
         """Read hessian and calculate force constants.
 
         Hessian elements include sqrt(mass_a * mass_b) of two atoms a and b.
@@ -772,7 +774,7 @@ class Vasprun:
 
     def _parse_expat_vasprun_xml(
         self, target: Literal["forces", "points", "energy"] = "forces"
-    ) -> Union[np.ndarray, float]:
+    ) -> np.ndarray | float:
         if self._is_version528():
             return self._parse_by_expat(VasprunWrapper(self._fileptr), target=target)
         else:
@@ -782,7 +784,7 @@ class Vasprun:
         self,
         fileptr: io.IOBase,
         target: Literal["forces", "points", "energy"] = "forces",
-    ) -> Union[np.ndarray, float]:
+    ) -> np.ndarray | float:
         if self._vasprun_expat is None:
             self._vasprun_expat = VasprunxmlExpat(fileptr)
             try:
@@ -913,91 +915,37 @@ class VasprunxmlExpat:
         self._p.ParseFile(self._fileptr)
 
     @property
-    def forces(self):
+    def forces(self) -> NDArray:
         """Return forces."""
         return np.array(self._all_forces, dtype="double", order="C")
 
-    def get_forces(self):
-        """Return forces."""
-        warnings.warn(
-            "VasprunxmlExpat.get_forces()) is deprecated. "
-            "Use VasprunxmlExpat.forces attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.forces
-
     @property
-    def stress(self):
+    def stress(self) -> NDArray:
         """Return stress tensor."""
         return np.array(self._all_stress, dtype="double", order="C")
 
-    def get_stress(self):
-        """Return stress tensor."""
-        warnings.warn(
-            "VasprunxmlExpat.get_stress()) is deprecated. "
-            "Use VasprunxmlExpat.stress attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.stress
-
     @property
-    def epsilon(self):
+    def epsilon(self) -> NDArray:
         """Return dielectric constant tensor."""
         return np.array(self._epsilon, dtype="double", order="C")
 
-    def get_epsilon(self):
-        """Return dielectric constant tensor."""
-        warnings.warn(
-            "VasprunxmlExpat.get_epsilon()) is deprecated. "
-            "Use VasprunxmlExpat.epsilon attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.epsilon
-
     @property
-    def efermi(self):
+    def efermi(self) -> float | None:
         """Return Fermi energy."""
         return self._efermi
 
-    def get_efermi(self):
-        """Return efermi."""
-        warnings.warn(
-            "VasprunxmlExpat.get_efermi()) is deprecated. "
-            "Use VasprunxmlExpat.efermi attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self._efermi
-
     @property
-    def born(self):
+    def born(self) -> NDArray:
         """Return Born effective charges."""
         return np.array(self._born, dtype="double", order="C")
 
-    def get_born(self):
-        """Return Born effective charges."""
-        return self.born
-
     @property
-    def points(self):
+    def points(self) -> NDArray:
         """Return all atomic positions of structure optimization steps."""
         return np.array(self._all_points, dtype="double", order="C")
 
-    def get_points(self):
-        """Return all atomic positions of structure optimization steps."""
-        warnings.warn(
-            "VasprunxmlExpat.get_points()) is deprecated. "
-            "Use VasprunxmlExpat.points attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.points
-
     @property
-    def lattice(self):
+    def lattice(self) -> NDArray:
         """Return all basis vectors of structure optimization steps.
 
         Each basis vectors are in row vectors (a, b, c)
@@ -1005,38 +953,18 @@ class VasprunxmlExpat:
         """
         return np.array(self._all_lattice, dtype="double", order="C")
 
-    def get_lattice(self):
-        """Return all basis vectors of structure optimization steps."""
-        warnings.warn(
-            "VasprunxmlExpat.get_lattice()) is deprecated. "
-            "Use VasprunxmlExpat.lattice attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.lattice
-
     @property
-    def volume(self):
+    def volume(self) -> NDArray:
         """Return all cell volumes of structure optimization steps."""
         return np.array(self._all_volumes, dtype="double")
 
     @property
-    def symbols(self):
+    def symbols(self) -> list[str]:
         """Return atomic symbols."""
         return self._symbols
 
-    def get_symbols(self):
-        """Return atomic symbols."""
-        warnings.warn(
-            "VasprunxmlExpat.get_symbols()) is deprecated. "
-            "Use VasprunxmlExpat.symbols attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self._symbols
-
     @property
-    def energies(self):
+    def energies(self) -> NDArray:
         """Return energies.
 
         Returns
@@ -1049,28 +977,18 @@ class VasprunxmlExpat:
         """
         return np.array(self._all_energies, dtype="double", order="C")
 
-    def get_energies(self):
-        """Return energies."""
-        warnings.warn(
-            "VasprunxmlExpat.get_energies()) is deprecated. "
-            "Use VasprunxmlExpat.energies attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.energies
-
     @property
-    def k_mesh(self):
+    def k_mesh(self) -> NDArray:
         """Return k_mesh."""
         return np.array(self._k_mesh, dtype="intc")
 
     @property
-    def kpointlist(self):
+    def kpointlist(self) -> NDArray:
         """Return kpoint list."""
         return np.array(self._kpointlist, dtype="double")
 
     @property
-    def k_weights(self):
+    def k_weights(self) -> NDArray:
         """Return k_weights.
 
         Returns
@@ -1084,18 +1002,8 @@ class VasprunxmlExpat:
         """
         return np.array(self._k_weights, dtype="double")
 
-    def get_k_weights(self):
-        """Return k_weights."""
-        warnings.warn(
-            "VasprunxmlExpat.get_k_weights()) is deprecated. "
-            "Use VasprunxmlExpat.k_weights attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.k_weights
-
     @property
-    def k_weights_int(self):
+    def k_weights_int(self) -> NDArray:
         """Return k_weights in integers.
 
         Returns
@@ -1113,7 +1021,7 @@ class VasprunxmlExpat:
         return np.array(weights, dtype="intc")
 
     @property
-    def eigenvalues(self):
+    def eigenvalues(self) -> NDArray:
         """Return eigenvalues.
 
         Returns
@@ -1126,33 +1034,13 @@ class VasprunxmlExpat:
         """
         return np.array(self._eigenvalues, dtype="double", order="C")
 
-    def get_eigenvalues(self):
-        """Return eigenvalues."""
-        warnings.warn(
-            "VasprunxmlExpat.get_eigenvalues()) is deprecated. "
-            "Use VasprunxmlExpat.eigenvalues attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.eigenvalues
-
     @property
-    def projectors(self):
+    def projectors(self) -> NDArray:
         """Return projectors."""
         return self._projectors
 
-    def get_projectors(self):
-        """Return projectors."""
-        warnings.warn(
-            "VasprunxmlExpat.get_projectors()) is deprecated. "
-            "Use VasprunxmlExpat.projectors attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.projectors
-
     @property
-    def pseudopotentials(self):
+    def pseudopotentials(self) -> list:
         """Return pseudo potential information.
 
         Example:
@@ -1162,18 +1050,8 @@ class VasprunxmlExpat:
         """
         return self._pseudopotentials
 
-    def get_pseudopotentials(self):
-        """Return pseudo potential information."""
-        warnings.warn(
-            "VasprunxmlExpat.get_pseudopotentials()) is deprecated. "
-            "Use VasprunxmlExpat.pseudopotentials attribute.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.pseudopotentials
-
     @property
-    def cell(self):
+    def cell(self) -> PhonopyAtoms:
         """Return cell in PhonopyAtoms."""
         return PhonopyAtoms(
             symbols=self._symbols,
@@ -1182,17 +1060,17 @@ class VasprunxmlExpat:
         )
 
     @property
-    def fft_grid(self):
+    def fft_grid(self) -> list[int, int, int]:
         """Return FFT gird [NGX, NGY, NGZ]."""
         return self._fft_grid
 
     @property
-    def fft_fine_grid(self):
+    def fft_fine_grid(self) -> list[int, int, int]:
         """Return fine FFT gird [NGXF, NGYF, NGZF]."""
         return self._fft_fine_grid
 
     @property
-    def NELECT(self):
+    def NELECT(self) -> float | None:
         """Return number of electrons, NELECT."""
         return self._NELECT
 
@@ -1604,7 +1482,7 @@ class VasprunxmlExpat:
             raise
 
 
-def parse_vasprunxml(filename):
+def parse_vasprunxml(filename: str | os.PathLike):
     """Parse vasprun.xml using VasprunxmlExpat."""
     if not os.path.exists(filename):
         print("File %s not found." % filename)
@@ -1625,7 +1503,7 @@ def parse_vasprunxml(filename):
 #
 # XDATCAR
 #
-def read_XDATCAR(filename: str = "XDATCAR", fileptr=None):
+def read_XDATCAR(filename: str = "XDATCAR", fileptr: typing.IO | None = None):
     """Read XDATCAR.
 
     filename : str, optional
@@ -1670,7 +1548,7 @@ def read_XDATCAR(filename: str = "XDATCAR", fileptr=None):
         return None
 
 
-def _read_XDATCAR_fileptr(f):
+def _read_XDATCAR_fileptr(f: typing.IO):
     f.readline()
     scale = float(f.readline())
     a = [float(x) for x in f.readline().split()[:3]]
@@ -1686,8 +1564,8 @@ def _read_XDATCAR_fileptr(f):
 
 def get_XDATCAR_lines_from_vasprunxml(
     vasprunxml_filename: str = "vasprun.xml",
-    vasprunxml_expat: Optional[VasprunxmlExpat] = None,
-    shift: Union[Sequence, np.ndarray] = None,
+    vasprunxml_expat: VasprunxmlExpat | None = None,
+    shift: ArrayLike | None = None,
 ):
     """Return XDATCAR lines from vasprun.xml or VasprunxmlExpat instance.
 
@@ -1725,10 +1603,10 @@ def get_XDATCAR_lines_from_vasprunxml(
 
 def write_XDATCAR(
     vasprunxml_filename: str = "vasprun.xml",
-    vasprunxml_expat: Optional[VasprunxmlExpat] = None,
+    vasprunxml_expat: VasprunxmlExpat | None = None,
     filename: str = "XDATCAR",
-    fileptr=Union[str, bytes, os.PathLike, io.IOBase],
-    shift: Union[Sequence, np.ndarray] = None,
+    fileptr: typing.IO | None = None,
+    shift: Sequence | np.ndarray | None = None,
 ):
     """Write XDATCAR from vasprun.xml or VasprunxmlExpat instance.
 
@@ -1750,12 +1628,12 @@ def write_XDATCAR(
 #
 # OUTCAR handling (obsolete)
 #
-def read_force_constants_OUTCAR(filename):
+def read_force_constants_OUTCAR(filename: str | os.PathLike):
     """Read force constants from OUTCAR."""
     return get_force_constants_OUTCAR(filename)
 
 
-def get_force_constants_OUTCAR(filename):
+def get_force_constants_OUTCAR(filename: str | os.PathLike):
     """Read force constants from OUTCAR."""
     file = open(filename)
     while 1:
