@@ -37,7 +37,7 @@
 from __future__ import annotations
 
 import numpy as np
-from numpy.typing import ArrayLike
+from numpy.typing import ArrayLike, NDArray
 
 from phonopy.harmonic.derivative_dynmat import DerivativeOfDynamicalMatrix
 from phonopy.harmonic.dynamical_matrix import DynamicalMatrix, DynamicalMatrixNAC
@@ -61,83 +61,80 @@ class IrReps:
 
     def __init__(
         self,
-        dynamical_matrix: DynamicalMatrix | DynamicalMatrixNAC,
+        dynamical_matrix: DynamicalMatrix,
         qpoint: ArrayLike,
+        primitive_symmetry: Symmetry,
         is_little_cogroup: bool = False,
         nac_q_direction: ArrayLike | None = None,
         factor: float | None = None,
-        symprec: float = 1e-5,
         degeneracy_tolerance: float | None = None,
         log_level: int = 0,
     ):
         """Init method."""
         self._is_little_cogroup = is_little_cogroup
-        self._nac_q_direction = nac_q_direction
-        if factor is None:
-            self._factor = get_physical_units().DefaultToTHz
-        else:
-            self._factor = factor
         self._log_level = log_level
 
         self._qpoint = np.array(qpoint)
-        if degeneracy_tolerance is None:
-            self._degeneracy_tolerance = 1e-5
-        else:
-            self._degeneracy_tolerance = degeneracy_tolerance
-        self._symprec = symprec
         self._primitive = dynamical_matrix.primitive
-        self._dynamical_matrix = dynamical_matrix
-        self._ddm = DerivativeOfDynamicalMatrix(dynamical_matrix)
-        self._character_table = None
-
-        self._symmetry_dataset = Symmetry(
-            self._primitive, symprec=self._symprec
-        ).dataset
-
+        self._symmetry_dataset = primitive_symmetry.dataset
         if not is_primitive_cell(self._symmetry_dataset.rotations):
             raise RuntimeError(
                 "Non-primitve cell is used. Your unit cell may be transformed to "
                 "a primitive cell by PRIMITIVE_AXIS tag."
             )
+        self._symprec = primitive_symmetry.tolerance
+        self._pointgroup_symbol = self._symmetry_dataset.pointgroup
+        self._rotations_at_q, self._translations_at_q = self._get_rotations_at_q()
 
-    def run(self):
+        self._freqs, self._eig_vecs = self._get_eigenvectors(
+            dynamical_matrix, nac_q_direction, factor
+        )
+        # Degeneracy for irreps has to be determined considering character tables, too.
+        # But currently only similarity of phonon frequencies is used to judge it.
+        if degeneracy_tolerance is None:
+            _degeneracy_tolerance = 1e-5
+        else:
+            _degeneracy_tolerance = degeneracy_tolerance
+        self._degenerate_sets = get_degenerate_sets(
+            self._freqs, cutoff=_degeneracy_tolerance
+        )
+        self._ddm = DerivativeOfDynamicalMatrix(dynamical_matrix)
+
+        self._transformation_matrix: NDArray
+        self._conventional_rotations: NDArray
+        self._ground_matrice: NDArray
+        self._irreps: list[NDArray]
+        self._characters: NDArray
+        self._irrep_dims: NDArray
+        self._run_irreps()
+
+        # Only at Gamma point
+        if (abs(self._qpoint) < self._symprec).all():
+            irrep_labels = IrRepLabels(
+                self._characters,
+                self._conventional_rotations,
+                self._pointgroup_symbol,
+                self._log_level > 0,
+            )
+            self._rotation_symbols = irrep_labels.rotation_symbols
+            self._ir_labels = irrep_labels.irrep_labels
+        else:
+            self._rotation_symbols = None
+            self._ir_labels = None
+
+    def _run_irreps(self):
         """Calculate irreps."""
-        self._set_eigenvectors(self._dynamical_matrix)
-        (self._rotations_at_q, self._translations_at_q) = self._get_rotations_at_q()
         (
-            self._pointgroup_symbol,
             self._transformation_matrix,
             self._conventional_rotations,
         ) = self._get_conventional_rotations()
-        self._rotation_symbols, self._character_table = self._get_rotation_symbols()
         self._ground_matrices = self._get_ground_matrix()
-
-        # Degeneracy for irreps has to be determined considering character tables, too.
-        # But currently only similarity of phonon frequencies is used to judge it.
-        self._degenerate_sets = self._get_degenerate_sets()
+        self._ddm.run(self._qpoint)
         self._irreps = self._get_irreps()
         self._characters, self._irrep_dims = self._get_characters()
-        self._ir_labels = None
-        if (abs(self._qpoint) < self._symprec).all():
-            self._ir_labels = self._get_ir_labels(
-                self._character_table, self._characters, self._rotation_symbols
-            )
-
-        if self._ir_labels is None:
-            if (abs(self._qpoint) < self._symprec).all():
-                if self._log_level > 0:
-                    print("Database for this point group is not prepared.")
-            else:
-                if self._log_level > 0 and self._rotation_symbols is not None:
-                    print("Database for non-Gamma point is not prepared.")
-
-    def _get_degenerate_sets(self):
-        deg_sets = get_degenerate_sets(self._freqs, cutoff=self._degeneracy_tolerance)
-        self._ddm.run(self._qpoint)
-        return deg_sets
 
     @property
-    def band_indices(self):
+    def band_indices(self) -> list[list[int]]:
         """Return band indices.
 
         Returns
@@ -148,36 +145,43 @@ class IrReps:
         return self._degenerate_sets
 
     @property
-    def characters(self):
+    def characters(self) -> NDArray:
         """Return characters of irreps."""
         return self._characters
 
     @property
-    def eigenvectors(self):
+    def eigenvectors(self) -> NDArray:
         """Return eigenvectors."""
         return self._eig_vecs
 
     @property
-    def irreps(self):
+    def frequencies(self) -> NDArray:
+        """Return frequencies in THz."""
+        return self._freqs
+
+    @property
+    def irreps(self) -> list[NDArray]:
         """Return irreps."""
         return self._irreps
 
     @property
-    def ground_matrices(self):
+    def ground_matrices(self) -> NDArray:
         """Return ground matrices."""
         return self._ground_matrices
 
     @property
-    def rotation_symbols(self):
+    def rotation_symbols(self) -> list[str] | None:
         """Return symbols assigned to rotation matrices."""
         return self._rotation_symbols
 
     @property
-    def conventional_rotations(self):
+    def conventional_rotations(self) -> NDArray:
         """Return rotation matrices."""
         return self._conventional_rotations
 
-    def get_projection_operators(self, idx_irrep, i=None, j=None):
+    def get_projection_operators(
+        self, idx_irrep: int, i: int | None = None, j: int | None = None
+    ) -> NDArray:
         """Return projection operators."""
         if i is None or j is None:
             return self._get_character_projection_operators(idx_irrep)
@@ -185,33 +189,46 @@ class IrReps:
             return self._get_projection_operators(idx_irrep, i, j)
 
     @property
-    def qpoint(self):
+    def qpoint(self) -> NDArray:
         """Return q-point."""
         return self._qpoint
 
-    def show(self, show_irreps=False):
+    def show(self, show_irreps: bool = False):
         """Show irreps."""
         self._show(show_irreps)
 
-    def write_yaml(self, show_irreps=False):
+    def write_yaml(self, show_irreps: bool = False):
         """Write irreps in yaml file."""
         self._write_yaml(show_irreps)
 
-    def _set_eigenvectors(self, dm):
-        if self._nac_q_direction is not None and (np.abs(self._qpoint) < 1e-5).all():
-            dm.run(self._qpoint, q_direction=self._nac_q_direction)
+    def _get_eigenvectors(
+        self,
+        dynamical_matrix: DynamicalMatrix,
+        nac_q_direction: ArrayLike | None,
+        factor: float | None,
+    ) -> tuple[NDArray, NDArray]:
+        if factor is None:
+            _factor = get_physical_units().DefaultToTHz
+        else:
+            _factor = factor
+        dm = dynamical_matrix
+        if isinstance(dm, DynamicalMatrixNAC):
+            dm.run(self._qpoint, q_direction=nac_q_direction)
         else:
             dm.run(self._qpoint)
-        eig_vals, self._eig_vecs = np.linalg.eigh(dm.dynamical_matrix)
-        self._freqs = np.sqrt(abs(eig_vals)) * np.sign(eig_vals) * self._factor
+        assert dm.dynamical_matrix is not None
+        eig_vals, eig_vecs = np.linalg.eigh(dm.dynamical_matrix)
+        freqs = np.sqrt(abs(eig_vals)) * np.sign(eig_vals) * _factor
+        return freqs, eig_vecs
 
-    def _get_rotations_at_q(self):
+    def _get_rotations_at_q(self) -> tuple[NDArray, NDArray]:
+        """Return little group of q."""
         rotations_at_q = []
         trans_at_q = []
         for r, t in zip(
             self._symmetry_dataset.rotations, self._symmetry_dataset.translations
         ):
-            diff = np.dot(self._qpoint, r) - self._qpoint
+            diff = self._qpoint @ r - self._qpoint
             if (abs(diff - np.rint(diff)) < self._symprec).all():
                 rotations_at_q.append(r)
                 for i in range(3):
@@ -221,26 +238,27 @@ class IrReps:
 
         return np.array(rotations_at_q), np.array(trans_at_q)
 
-    def _get_conventional_rotations(self):
+    def _get_conventional_rotations(self) -> tuple[NDArray, NDArray]:
         rotations = self._rotations_at_q.copy()
-        pointgroup_symbol = self._symmetry_dataset.pointgroup
         transformation_matrix = self._symmetry_dataset.transformation_matrix
         conventional_rotations = self._transform_rotations(
             transformation_matrix, rotations
         )
 
-        return (pointgroup_symbol, transformation_matrix, conventional_rotations)
+        return transformation_matrix, conventional_rotations
 
-    def _transform_rotations(self, tmat, rotations):
+    def _transform_rotations(
+        self, transformation_matrix: NDArray, rotations: NDArray
+    ) -> NDArray:
         trans_rots = []
 
         for r in rotations:
-            r_conv = similarity_transformation(tmat, r)
+            r_conv = similarity_transformation(transformation_matrix, r)
             trans_rots.append(np.rint(r_conv).astype(int))
 
         return np.array(trans_rots)
 
-    def _get_ground_matrix(self):
+    def _get_ground_matrix(self) -> NDArray:
         matrices = []
 
         for r, t in zip(self._rotations_at_q, self._translations_at_q):
@@ -251,7 +269,7 @@ class IrReps:
 
         return np.array(matrices)
 
-    def _get_characters(self):
+    def _get_characters(self) -> tuple[NDArray, NDArray]:
         characters = []
         irrep_dims = []
         for irrep_Rs in self._irreps:
@@ -259,24 +277,23 @@ class IrReps:
             irrep_dims.append(len(irrep_Rs[0]))
         return np.array(characters), np.array(irrep_dims)
 
-    def _get_modified_permutation_matrix(self, r, t):
+    def _get_modified_permutation_matrix(self, r: NDArray, t: NDArray) -> NDArray:
         num_atom = len(self._primitive)
         pos = self._primitive.scaled_positions
         matrix = np.zeros((num_atom, num_atom), dtype=complex)
         for i, p1 in enumerate(pos):
-            p_rot = np.dot(r, p1) + t  # i -> j
+            p_rot = r @ p1 + t  # i -> j
             for j, p2 in enumerate(pos):
                 diff = p_rot - p2  # Rx_i + t - x_j
-                if (abs(diff - np.rint(diff)) < self._symprec).all():
-                    phase_factor = np.dot(
-                        self._qpoint, np.dot(np.linalg.inv(r), p2 - t) - p2
-                    )
+                diff -= np.rint(diff)
+                if (np.linalg.norm(diff @ self._primitive.cell) < self._symprec).all():
+                    phase_factor = self._qpoint @ (np.linalg.inv(r) @ (p2 - t) - p2)
                     if self._is_little_cogroup:
-                        phase_factor = np.dot(t, self._qpoint)
+                        phase_factor = t @ self._qpoint
                     matrix[j, i] = np.exp(2j * np.pi * phase_factor)
         return matrix
 
-    def _get_irreps(self):
+    def _get_irreps(self) -> list[NDArray]:
         eigvecs = self._eig_vecs.T
         irreps = []
         for band_indices in self._degenerate_sets:
@@ -286,7 +303,7 @@ class IrReps:
 
                 if n_deg == 1:
                     vec = eigvecs[band_indices[0]]
-                    irrep_Rs.append([[np.vdot(vec, np.dot(mat, vec))]])
+                    irrep_Rs.append([[np.vdot(vec, mat @ vec)]])
                     continue
 
                 irrep_R = np.zeros((n_deg, n_deg), dtype=complex)
@@ -294,14 +311,14 @@ class IrReps:
                     vec_i = eigvecs[b_i]
                     for j, b_j in enumerate(band_indices):
                         vec_j = eigvecs[b_j]
-                        irrep_R[i, j] = np.vdot(vec_i, np.dot(mat, vec_j))
+                        irrep_R[i, j] = np.vdot(vec_i, mat @ vec_j)
                 irrep_Rs.append(irrep_R)
 
             irreps.append(np.array(irrep_Rs))
 
         return irreps
 
-    def _get_character_projection_operators(self, idx_irrep):
+    def _get_character_projection_operators(self, idx_irrep: int) -> NDArray:
         dim = self._irrep_dims[idx_irrep]
         chars = self._characters[idx_irrep]
         return (
@@ -313,7 +330,7 @@ class IrReps:
             / len(self._rotations_at_q)
         )
 
-    def _get_projection_operators(self, idx_irrep, i, j):
+    def _get_projection_operators(self, idx_irrep: int, i: int, j: int) -> NDArray:
         dim = self._irrep_dims[idx_irrep]
         return (
             np.sum(
@@ -327,66 +344,7 @@ class IrReps:
             / len(self._rotations_at_q)
         )
 
-    def _get_rotation_symbols(self):
-        # Check availability of database
-        if (
-            self._pointgroup_symbol not in character_table.keys()
-            or character_table[self._pointgroup_symbol] is None
-        ):
-            return None, None
-
-        for ct in character_table[self._pointgroup_symbol]:
-            mapping_table = ct["mapping_table"]
-            rotation_symbols = []
-            for r in self._conventional_rotations:
-                rotation_symbols.append(_get_rotation_symbol(r, mapping_table))
-            if False not in rotation_symbols:
-                break
-
-        if False in rotation_symbols:
-            return None, None
-
-        return rotation_symbols, ct
-
-    def _get_ir_labels(self, character_table, characters, rotation_symbols):
-        if rotation_symbols is None:
-            return None
-
-        ir_labels = []
-        rot_list = character_table["rotation_list"]
-        char_table = character_table["character_table"]
-        for chars in characters:
-            chars_ordered = np.zeros(len(rot_list), dtype=complex)
-            for rs, ch in zip(rotation_symbols, chars):
-                chars_ordered[rot_list.index(rs)] += ch
-
-            for i, rl in enumerate(rot_list):
-                chars_ordered[i] /= len(character_table["mapping_table"][rl])
-
-            found = False
-            for ct_label in char_table.keys():
-                if (
-                    abs(chars_ordered - np.array(char_table[ct_label])) < self._symprec
-                ).all():
-                    ir_labels.append(ct_label)
-                    found = True
-                    break
-
-            if not found:
-                ir_labels.append(None)
-
-            if self._log_level > 1:
-                text = ""
-                for v in chars_ordered:
-                    text += "%5.2f " % abs(v)
-                if found:
-                    print("%s %s" % (text, ct_label))
-                else:
-                    print("%s Not found" % text)
-
-        return ir_labels
-
-    def _show(self, show_irreps):
+    def _show(self, show_irreps: bool):
         print("")
         print("-------------------------------")
         print("  Irreducible representations")
@@ -413,7 +371,7 @@ class IrReps:
         for v in self._transformation_matrix:
             print("%6.3f %6.3f %6.3f" % tuple(v))
         print("")
-        print("Rotation matrices by transformation matrix:")
+        print("Rotation matrices after transformation matrix:")
         print("")
         _print_rotations(
             self._conventional_rotations,
@@ -479,79 +437,78 @@ class IrReps:
             if len(irrep_R) == 1:
                 print("")
 
-    def _write_yaml(self, show_irreps):
-        w = open("irreps.yaml", "w")
-        w.write("q-position: [ %12.7f, %12.7f, %12.7f ]\n" % tuple(self._qpoint))
-        w.write("point_group: %s\n" % self._pointgroup_symbol)
-        w.write("transformation_matrix:\n")
+    def _write_yaml(self, show_irreps: bool):
+        lines = []
+        lines.append("q-position: [ %12.7f, %12.7f, %12.7f ]" % tuple(self._qpoint))
+        lines.append("point_group: %s" % self._pointgroup_symbol)
+        lines.append("transformation_matrix:")
         for v in self._transformation_matrix:
-            w.write("- [ %10.7f, %10.7f, %10.7f ]\n" % tuple(v))
-        w.write("rotations:\n")
+            lines.append("- [ %10.7f, %10.7f, %10.7f ]" % tuple(v))
+        lines.append("rotations:")
         for i, r in enumerate(self._conventional_rotations):
-            w.write("- matrix:\n")
+            lines.append("- matrix:")
             for v in r:
-                w.write("  - [ %2d, %2d, %2d ]\n" % tuple(v))
+                lines.append("  - [ %2d, %2d, %2d ]" % tuple(v))
             if self._rotation_symbols:
-                w.write("  symbol: %s\n" % self._rotation_symbols[i])
-        w.write("normal_modes:\n")
+                lines.append("  symbol: %s" % self._rotation_symbols[i])
+        lines.append("normal_modes:")
         for i, deg_set in enumerate(self._degenerate_sets):
-            w.write("- band_indices: [ ")
-            w.write("%d" % (deg_set[0] + 1))
+            text = "- band_indices: [ "
+            text += "%d" % (deg_set[0] + 1)
             for bi in deg_set[1:]:
-                w.write(", %d" % (bi + 1))
-            w.write(" ]\n")
-            w.write("  frequency: %-15.10f\n" % self._freqs[deg_set[0]])
+                text += ", %d" % (bi + 1)
+            text += " ]"
+            lines.append(text)
+            lines.append("  frequency: %-15.10f" % self._freqs[deg_set[0]])
             if self._ir_labels:
-                w.write("  ir_label: %s\n" % self._ir_labels[i])
-            w.write("  characters: ")
+                lines.append("  ir_label: %s" % self._ir_labels[i])
+            text = "  characters: "
             chars = np.rint(np.abs(self._characters[i]))
             phase = (np.angle(self._characters[i]) / np.pi * 180) % 360
             if len(chars) > 1:
-                w.write("[ [ %2d, %5.1f ]" % (chars[0], phase[0]))
+                text += "[ [ %2d, %5.1f ]" % (chars[0], phase[0])
                 for chi, theta in zip(chars[1:], phase[1:]):
-                    w.write(", [ %2d, %5.1f ]" % (chi, theta))
-                w.write(" ]\n")
+                    text += ", [ %2d, %5.1f ]" % (chi, theta)
+                text += " ]"
             else:
-                w.write("[ [ %2d, %5.1f ] ]\n" % (chars[0], phase[0]))
+                text += "[ [ %2d, %5.1f ] ]" % (chars[0], phase[0])
+            lines.append(text)
 
         if show_irreps:
-            self._write_yaml_irreps(w)
+            self._write_yaml_irreps(lines)
 
-        w.close()
+        with open("irreps.yaml", "w") as w:
+            print("\n".join(lines), file=w)
 
-    def _write_yaml_irreps(self, file_pointer):
-        w = file_pointer
-        if not self._irreps:
-            self._irrep = self._get_irreps()
-
-        w.write("\n")
-        w.write("irreps:\n")
+    def _write_yaml_irreps(self, lines: list[str]):
+        lines.append("")
+        lines.append("irreps:")
         for i, (deg_set, irrep_Rs) in enumerate(
             zip(self._degenerate_sets, self._irreps)
         ):
-            w.write("- # %d\n" % (i + 1))
+            lines.append("- # %d" % (i + 1))
             for j, irrep_R in enumerate(irrep_Rs):
                 if self._rotation_symbols:
                     symbol = self._rotation_symbols[j]
                 else:
                     symbol = ""
                 if len(deg_set) > 1:
-                    w.write("  - # %d %s\n" % (j + 1, symbol))
+                    lines.append("  - # %d %s" % (j + 1, symbol))
                     for _, v in enumerate(irrep_R):
-                        w.write("    - [ ")
+                        text = "    - [ "
                         for x in v[:-1]:
-                            w.write("%10.7f, %10.7f,   " % (x.real, x.imag))
-                        w.write("%10.7f, %10.7f ] # (" % (v[-1].real, v[-1].imag))
+                            text += "%10.7f, %10.7f,   " % (x.real, x.imag)
+                        text += "%10.7f, %10.7f ] # (" % (v[-1].real, v[-1].imag)
 
-                        w.write(
-                            ("%5.0f" * len(v))
-                            % tuple((np.angle(v) / np.pi * 180) % 360)
+                        text += ("%5.0f" * len(v)) % tuple(
+                            (np.angle(v) / np.pi * 180) % 360
                         )
-                        w.write(")\n")
+                        text += ")"
+                        lines.append(text)
                 else:
                     x = irrep_R[0][0]
-                    w.write(
-                        "  - [ [ %10.7f, %10.7f ] ] # (%3.0f) %d %s\n"
+                    lines.append(
+                        "  - [ [ %10.7f, %10.7f ] ] # (%3.0f) %d %s"
                         % (
                             x.real,
                             x.imag,
@@ -561,19 +518,8 @@ class IrReps:
                         )
                     )
 
-        pass
 
-
-def _get_rotation_symbol(rotation, mapping_table):
-    for k in mapping_table:
-        v = mapping_table[k]
-        for r in v:
-            if (r == rotation).all():
-                return k
-    return False
-
-
-def _print_characters(characters, width=6):
+def _print_characters(characters: NDArray, width: int = 6):
     text = ""
     for i, c in enumerate(characters):
         angle = np.angle(c) / np.pi * 180
@@ -592,7 +538,14 @@ def _print_characters(characters, width=6):
             text = ""
 
 
-def _get_rotation_text(rotations, translations, rotation_symbols, width, num_rest, i):
+def _get_rotation_text(
+    rotations: NDArray,
+    translations: NDArray | None,
+    rotation_symbols: list[str] | None,
+    width: int,
+    num_rest: int,
+    i: int,
+) -> str:
     lines = []
     if rotation_symbols is None:
         if translations is None:
@@ -641,7 +594,12 @@ def _get_rotation_text(rotations, translations, rotation_symbols, width, num_res
     return "\n".join(lines)
 
 
-def _print_rotations(rotations, translations=None, rotation_symbols=None, width=6):
+def _print_rotations(
+    rotations: NDArray,
+    translations: NDArray | None = None,
+    rotation_symbols: list[str] | None = None,
+    width: int = 6,
+):
     for i in range(len(rotations) // width):
         print(
             _get_rotation_text(
@@ -657,3 +615,100 @@ def _print_rotations(rotations, translations=None, rotation_symbols=None, width=
                 rotations, translations, rotation_symbols, width, num_rest, i
             )
         )
+
+
+class IrRepLabels:
+    """Class to assign ir labels to irreps."""
+
+    def __init__(
+        self,
+        characters: NDArray,
+        conventional_rotations: NDArray,
+        pointgroup_symbol: str,
+        verbose: bool,
+    ):
+        self._characters = characters
+        self._conventional_rotations = conventional_rotations
+        self._verbose = verbose
+
+        self._rotation_symbols, character_table_of_ptg = self._get_rotation_symbols(
+            pointgroup_symbol
+        )
+        self._irrep_labels = self._get_irrep_labels(character_table_of_ptg)
+        if self._verbose and self._irrep_labels is None:
+            print("Database for this point group is not prepared.")
+
+    @property
+    def rotation_symbols(self) -> list[str]:
+        """Return rotation symbols."""
+        return self._rotation_symbols
+
+    @property
+    def irrep_labels(self) -> list[str | None] | None:
+        """Return irrep labels."""
+        return self._irrep_labels
+
+    def _get_rotation_symbols(self, pointgroup_symbol: str) -> tuple[list[str], dict]:
+        # Check availability of database
+        if (
+            pointgroup_symbol not in character_table.keys()
+            or character_table[pointgroup_symbol] is None
+        ):
+            raise RuntimeError("Character table not found.")
+
+        # Loop over possible sets of character tables for the point group
+        # Among them, only one set can fit.
+        for ct in character_table[pointgroup_symbol]:
+            mapping_table: dict = ct["mapping_table"]
+            rotation_symbols = []
+            for r in self._conventional_rotations:
+                rotation_symbols.append(_get_rotation_symbol(r, mapping_table))
+            if None not in rotation_symbols:
+                break
+
+        if None in rotation_symbols:
+            raise RuntimeError("Rotation symbols not found.")
+
+        return rotation_symbols, ct
+
+    def _get_irrep_labels(self, character_table_of_ptg: dict) -> list[str | None]:
+        ir_labels = []
+        rot_list = character_table_of_ptg["rotation_list"]
+        char_table = character_table_of_ptg["character_table"]
+        for chars in self._characters:
+            chars_ordered = np.zeros(len(rot_list), dtype=complex)
+            for rs, ch in zip(self._rotation_symbols, chars):
+                chars_ordered[rot_list.index(rs)] += ch
+
+            for i, rl in enumerate(rot_list):
+                chars_ordered[i] /= len(character_table_of_ptg["mapping_table"][rl])
+
+            found = False
+            for ct_label in char_table.keys():
+                if (abs(chars_ordered - np.array(char_table[ct_label])) < 1e-5).all():
+                    ir_labels.append(ct_label)
+                    found = True
+                    break
+
+            if not found:
+                ir_labels.append(None)
+
+            if self._verbose > 1:
+                text = ""
+                for v in chars_ordered:
+                    text += "%5.2f " % abs(v)
+                if found:
+                    print("%s %s" % (text, ct_label))
+                else:
+                    print("%s Not found" % text)
+
+        return ir_labels
+
+
+def _get_rotation_symbol(rotation: NDArray, mapping_table: dict) -> str | None:
+    for rotation_symbol in mapping_table:
+        rot_mats = mapping_table[rotation_symbol]
+        for r in rot_mats:
+            if (r == rotation).all():
+                return rotation_symbol
+    return None
