@@ -212,6 +212,28 @@ def ph_tio2() -> Phonopy:
     )
 
 
+@pytest.fixture(scope="session")
+def ph_tio2_nofcsym() -> Phonopy:
+    """Return Phonopy class instance of anataze TiO2 3x3x1.
+
+    Without symmetrizing force constants.
+    Full FC.
+
+    """
+    yaml_filename = cwd / "phonopy_disp_TiO2.yaml"
+    force_sets_filename = cwd / "FORCE_SETS_TiO2"
+    born_filename = cwd / "BORN_TiO2"
+    return phonopy.load(
+        yaml_filename,
+        force_sets_filename=force_sets_filename,
+        born_filename=born_filename,
+        is_compact_fc=False,
+        symmetrize_fc=False,
+        log_level=1,
+        produce_fc=True,
+    )
+
+
 @pytest.fixture(scope="session")
 def ph_zr3n4() -> Phonopy:
     """Return Phonopy class instance of anataze Zr3N4 1x1x1."""
@@ -221,6 +243,42 @@ def ph_zr3n4() -> Phonopy:
     )
 
 
+@pytest.fixture(scope="session")
+def ph_zr3n4_nofcsym() -> Phonopy:
+    """Return Phonopy class instance of anataze Zr3N4 1x1x1.
+
+    Without symmetrizing force constants.
+    Full FC.
+
+    """
+    yaml_filename = cwd / "phonopy_params_Zr3N4.yaml"
+    return phonopy.load(
+        yaml_filename,
+        is_compact_fc=False,
+        symmetrize_fc=False,
+        log_level=1,
+        produce_fc=True,
+    )
+
+
+@pytest.fixture(scope="session")
+def ph_zr3n4_nofcsym_compact_fc() -> Phonopy:
+    """Return Phonopy class instance of anataze Zr3N4 1x1x1.
+
+    Without symmetrizing force constants.
+    Compact FC.
+
+    """
+    yaml_filename = cwd / "phonopy_params_Zr3N4.yaml"
+    return phonopy.load(
+        yaml_filename,
+        is_compact_fc=True,
+        symmetrize_fc=False,
+        log_level=1,
+        produce_fc=True,
+    )
+
+
 @pytest.fixture(scope="session")
 def ph_tipn3() -> Phonopy:
     """Return Phonopy class instance of anataze TiPN3 4x2x1."""
