@@ -1,7 +1,6 @@
 """Tests for displacements."""
 
 import itertools
-from copy import deepcopy
 from typing import Literal, Optional, Union
 
 import numpy as np
@@ -12,27 +11,25 @@ from phonopy import Phonopy
 
 def test_nacl(ph_nacl: Phonopy):
     """Test displacements of NaCl 2x2x2."""
-    dataset = deepcopy(ph_nacl.dataset)
+    ph = ph_nacl.copy()
     disp_ref = [[0, 0.01, 0.0, 0.0], [32, 0.01, 0.0, 0.0]]
     np.testing.assert_allclose(ph_nacl.displacements, disp_ref, atol=1e-8)
-    ph_nacl.generate_displacements()
-    np.testing.assert_allclose(ph_nacl.displacements, disp_ref, atol=1e-8)
-    ph_nacl.dataset = dataset
+    ph.generate_displacements()
+    np.testing.assert_allclose(ph.displacements, disp_ref, atol=1e-8)
 
 
 def test_si(ph_si: Phonopy):
     """Test displacements of Si."""
-    dataset = deepcopy(ph_si.dataset)
+    ph = ph_si.copy()
     disp_ref = [[0, 0.0, 0.0070710678118655, 0.0070710678118655]]
     np.testing.assert_allclose(ph_si.displacements, disp_ref, atol=1e-8)
-    ph_si.generate_displacements()
-    np.testing.assert_allclose(ph_si.displacements, disp_ref, atol=1e-8)
-    ph_si.dataset = dataset
+    ph.generate_displacements()
+    np.testing.assert_allclose(ph.displacements, disp_ref, atol=1e-8)
 
 
 def test_sno2(ph_sno2: Phonopy):
     """Test displacements of SnO2."""
-    dataset = deepcopy(ph_sno2.dataset)
+    ph = ph_sno2.copy()
     disp_ref = [
         [0, 0.01, 0.0, 0.0],
         [0, -0.01, 0.0, 0.0],
@@ -41,28 +38,26 @@ def test_sno2(ph_sno2: Phonopy):
         [48, 0.0, 0.0, 0.01],
     ]
     np.testing.assert_allclose(ph_sno2.displacements, disp_ref, atol=1e-8)
-    ph_sno2.generate_displacements()
+    ph.generate_displacements()
     disp_gen = [
         [0, 0.007032660602415084, 0.0, 0.007109267532681459],
         [0, -0.007032660602415084, 0.0, -0.007109267532681459],
         [48, 0.007032660602415084, 0.0, 0.007109267532681459],
     ]
-    np.testing.assert_allclose(ph_sno2.displacements, disp_gen, atol=1e-8)
-    ph_sno2.dataset = dataset
+    np.testing.assert_allclose(ph.displacements, disp_gen, atol=1e-8)
 
 
 def test_tio2(ph_tio2: Phonopy):
     """Test displacements of TiO2."""
-    dataset = deepcopy(ph_tio2.dataset)
-    ph_tio2.generate_displacements()
+    ph = ph_tio2.copy()
+    ph.generate_displacements()
     disp_gen = [
         [0, 0.0060687317141537135, 0.0060687317141537135, 0.0051323474905008],
         [0, -0.0060687317141537135, -0.0060687317141537135, -0.0051323474905008],
         [72, 0.007635558297727332, 0.0, 0.006457418174627326],
         [72, -0.007635558297727332, 0.0, -0.006457418174627326],
     ]
-    np.testing.assert_allclose(ph_tio2.displacements, disp_gen, atol=1e-8)
-    ph_tio2.dataset = dataset
+    np.testing.assert_allclose(ph.displacements, disp_gen, atol=1e-8)
 
 
 @pytest.mark.parametrize(
@@ -82,13 +77,13 @@ def test_tio2_random_disp(
     """
     pytest.importorskip("symfc")
 
-    dataset = deepcopy(ph_tio2.dataset)
-    ph_tio2.generate_displacements(
+    ph = ph_tio2.copy()
+    ph.generate_displacements(
         number_of_snapshots=number_of_snapshots,
         distance=distance,
         is_plusminus=is_plusminus,
     )
-    d = ph_tio2.displacements
+    d = ph.displacements
 
     if number_of_snapshots == "auto":
         assert len(d) == 4 * (is_plusminus + 1)
@@ -101,7 +96,31 @@ def test_tio2_random_disp(
         np.testing.assert_allclose(np.linalg.norm(d, axis=2).ravel(), 0.03, atol=1e-8)
     if is_plusminus:
         np.testing.assert_allclose(d[: len(d) // 2], -d[len(d) // 2 :], atol=1e-8)
-    ph_tio2.dataset = dataset
+
+
+def test_tio2_random_disp_rd_auto_estimation_factor(ph_tio2: Phonopy):
+    """Test random displacements of TiO2.
+
+    Test for Phonopy.generate_displacements(number_of_snapshots='auto',
+    number_estimation_factor=NUM)
+
+    """
+    pytest.importorskip("symfc")
+
+    ph = ph_tio2.copy()
+    ph.generate_displacements(number_of_snapshots="auto")
+    assert len(ph.displacements) == 4
+
+    ph.generate_displacements(number_of_snapshots="auto", number_estimation_factor=10)
+    assert len(ph.displacements) == 10
+
+    ph.generate_displacements(number_of_snapshots="auto", max_distance=1.5)
+    assert len(ph.displacements) == 8
+
+    ph.generate_displacements(
+        number_of_snapshots="auto", max_distance=1.5, number_estimation_factor=10
+    )
+    assert len(ph.displacements) == 10
 
 
 @pytest.mark.parametrize("min_distance", [None, 0.05, 0.2])
@@ -109,27 +128,25 @@ def test_tio2_random_disp_with_random_dist(
     ph_tio2: Phonopy, min_distance: Optional[float]
 ):
     """Test random displacements with random distance of TiO2."""
-    dataset = deepcopy(ph_tio2.dataset)
+    ph = ph_tio2.copy()
 
     if min_distance is not None and min_distance > 0.1:
         with pytest.raises(RuntimeError):
-            ph_tio2.generate_displacements(
+            ph.generate_displacements(
                 number_of_snapshots=1, max_distance=0.1, distance=min_distance
             )
     else:
         n_snapshots = 100
-        ph_tio2.generate_displacements(
+        ph.generate_displacements(
             number_of_snapshots=n_snapshots, distance=min_distance, max_distance=0.1
         )
-        d = ph_tio2.displacements
+        d = ph.displacements
         assert len(d) == n_snapshots
         dists = np.linalg.norm(d, axis=2).ravel()
         assert (dists < 0.1 + 1e-8).all()
         if min_distance is not None:
             assert (dists > min_distance - 1e-8).all()
 
-    ph_tio2.dataset = dataset
-
 
 @pytest.mark.parametrize("max_distance", [None, 0.1])
 def test_tio2_random_disp_with_random_dist_defualt(
@@ -140,13 +157,13 @@ def test_tio2_random_disp_with_random_dist_defualt(
     Combination of default distance and max_distance.
 
     """
-    dataset = deepcopy(ph_tio2.dataset)
+    ph = ph_tio2.copy()
 
     n_snapshots = 100
-    ph_tio2.generate_displacements(
+    ph.generate_displacements(
         number_of_snapshots=n_snapshots, max_distance=max_distance, distance=0.01
     )
-    d = ph_tio2.displacements
+    d = ph.displacements
     assert len(d) == n_snapshots
     dists = np.linalg.norm(d, axis=2).ravel()
     if max_distance is None:
@@ -154,8 +171,6 @@ def test_tio2_random_disp_with_random_dist_defualt(
     else:
         assert (dists < max_distance + 1e-8).all() and (dists > 0.01 - 1e-8).all()
 
-    ph_tio2.dataset = dataset
-
 
 def test_tio2_random_disp_with_random_max_distance(ph_tio2: Phonopy):
     """Test random displacements with random distance of TiO2.
@@ -163,19 +178,17 @@ def test_tio2_random_disp_with_random_max_distance(ph_tio2: Phonopy):
     Combination of distance and max_distance parameters.
 
     """
-    dataset = deepcopy(ph_tio2.dataset)
+    ph = ph_tio2.copy()
 
     n_snapshots = 100
-    ph_tio2.generate_displacements(
+    ph.generate_displacements(
         number_of_snapshots=n_snapshots, distance=0.01, max_distance=0.1
     )
-    d = ph_tio2.displacements
+    d = ph.displacements
     assert len(d) == n_snapshots
     dists = np.linalg.norm(d, axis=2).ravel()
     assert (dists < 0.1 + 1e-8).all()
 
-    ph_tio2.dataset = dataset
-
 
 def test_tio2_random_disp_plusminus(ph_tio2: Phonopy):
     """Test random plus-minus displacements of TiO2.
@@ -185,7 +198,7 @@ def test_tio2_random_disp_plusminus(ph_tio2: Phonopy):
     Displacements of last 4 supercells are minus of those of first 4 supercells.
 
     """
-    dataset = deepcopy(ph_tio2.dataset)
+    ph = ph_tio2.copy()
     disp_ref = [
         [0, 0.01, 0.0, 0.0],
         [0, 0.0, 0.01, 0.0],
@@ -195,36 +208,31 @@ def test_tio2_random_disp_plusminus(ph_tio2: Phonopy):
         [72, 0.0, 0.0, 0.01],
     ]
     np.testing.assert_allclose(ph_tio2.displacements, disp_ref, atol=1e-8)
-    ph_tio2.generate_displacements(
-        number_of_snapshots=4, distance=0.03, is_plusminus=True
-    )
-    d = ph_tio2.displacements
+    ph.generate_displacements(number_of_snapshots=4, distance=0.03, is_plusminus=True)
+    d = ph.displacements
     np.testing.assert_allclose(d[:4], -d[4:], atol=1e-8)
     np.testing.assert_allclose(np.linalg.norm(d, axis=2).ravel(), 0.03, atol=1e-8)
-    ph_tio2.dataset = dataset
 
 
 def test_tio2_random_distances(ph_tio2: Phonopy):
     """Test random distance displacements with random directions of TiO2."""
-    dataset = deepcopy(ph_tio2.dataset)
-
+    ph = ph_tio2.copy()
     n_snapshots = 100
-    ph_tio2.generate_displacements(
+    ph.generate_displacements(
         number_of_snapshots=n_snapshots,
         max_distance=0.1,
         distance=0.01,
     )
-    d = ph_tio2.displacements
+    d = ph.displacements
     assert len(d) == n_snapshots
     dists = np.linalg.norm(d, axis=2)
     for dist_supercell in dists:
         np.testing.assert_allclose(dist_supercell[0], dist_supercell, atol=1e-10)
-    ph_tio2.dataset = dataset
 
 
 def test_zr3n4(ph_zr3n4: Phonopy):
     """Test displacements of Zr3N4."""
-    dataset = deepcopy(ph_zr3n4.dataset)
+    ph = ph_zr3n4.copy()
     disp_ref = [
         [0, 0.01, 0.0, 0.0],
         [0, -0.01, 0.0, 0.0],
@@ -232,20 +240,19 @@ def test_zr3n4(ph_zr3n4: Phonopy):
         [16, 0.0, 0.01, 0.0],
     ]
     np.testing.assert_allclose(ph_zr3n4.displacements, disp_ref, atol=1e-8)
-    ph_zr3n4.generate_displacements()
+    ph.generate_displacements()
     disp_gen = [
         [0, 0.01, 0.0, 0.0],
         [0, -0.01, 0.0, 0.0],
         [16, 0.007071067811865475, 0.007071067811865475, 0.0],
         [16, -0.007071067811865475, -0.007071067811865475, 0.0],
     ]
-    np.testing.assert_allclose(ph_zr3n4.displacements, disp_gen, atol=1e-8)
-    ph_zr3n4.dataset = dataset
+    np.testing.assert_allclose(ph.displacements, disp_gen, atol=1e-8)
 
 
 def test_tipn3(ph_tipn3: Phonopy):
     """Test displacements of Zr3N4."""
-    dataset = deepcopy(ph_tipn3.dataset)
+    ph = ph_tipn3.copy()
     disp_ref = [
         [0, 0.01, 0.0, 0.0],
         [0, 0.0, 0.01, 0.0],
@@ -266,7 +273,7 @@ def test_tipn3(ph_tipn3: Phonopy):
         [40, 0.0, 0.0, -0.01],
     ]
     np.testing.assert_allclose(ph_tipn3.displacements, disp_ref, atol=1e-8)
-    ph_tipn3.generate_displacements()
+    ph.generate_displacements()
     disp_gen = [
         [0, 0.006370194270018462, 0.006021020526083804, 0.00481330829956917],
         [0, -0.006370194270018462, -0.006021020526083804, -0.00481330829956917],
@@ -279,5 +286,4 @@ def test_tipn3(ph_tipn3: Phonopy):
         [40, 0.006370194270018462, 0.006021020526083804, 0.00481330829956917],
         [40, -0.006370194270018462, -0.006021020526083804, -0.00481330829956917],
     ]
-    np.testing.assert_allclose(ph_tipn3.displacements, disp_gen, atol=1e-8)
-    ph_tipn3.dataset = dataset
+    np.testing.assert_allclose(ph.displacements, disp_gen, atol=1e-8)
